<?php
    
    /**
     * @var View           $this
     * @var string         $content
     * @var SeoComponent   $seo
     * @var User           $user
     * @var PageCategory[] $pageCategories
     * @var \artbox\core\forms\Module $module;
     */
    
    use artbox\core\components\SeoComponent;
    use artbox\core\helpers\ImageHelper;
    use artbox\core\models\Feedback;
    use artbox\core\models\PageCategory;
    use artbox\core\models\User;
    use common\models\page\Category;
    use common\models\Settings;
    use frontend\assets\AppAsset;
    use artbox\core\components\imagemanager\models\ImageManager;
    use frontend\widgets\ArtboxModalWidget;
    use frontend\widgets\LanguageWidget;
    use yii\bootstrap\Nav;
    use yii\bootstrap\Html;
    use yii\db\ActiveQuery;
    use artbox\core\helpers\Url;
    use yii\web\View;
    use yii\widgets\Breadcrumbs;
    
    
    AppAsset::register($this);
    $user = \Yii::$app->user->identity;
    $seo = Yii::$app->get('seo');
    $feedback = new Feedback();
    $settings = Settings::getInstance();
    $controller = Yii::$app->controller;
    $default_controller = Yii::$app->defaultRoute;
    $isHome = ( ( $controller->id === $default_controller ) && ( $controller->action->id === $controller->defaultAction ) ) ? true : false;
    $pageCategories = Category::find()
                                  ->with(
                                      [
                                          'language',
                                          'pages' => function (ActiveQuery $query) {
                                              $query->with('language.alias')
                                                    ->where(['in_menu' => true])
                                                    ->orderBy([ 'sort' => SORT_ASC ]);
                                          },
                                      ]
                                  )
                                  ->where([ 'status' => true ])
                                  ->orderBy([ 'sort' => SORT_ASC ])
                                  ->all();
    $logo = null;
    if ($settings->logo) {
        $logo_img = ImageManager::findOne($settings->logo);
        if ($logo_img) {
            $logo = $logo_img->getImagePathPrivate() ?? $logo;
        }
    }
    
    $this->registerMetaTag(
        [
            'name'    => 'description',
            'content' => $seo->desc,
        ]
    );
    $module = \Yii::$app->getModule('feedback');
?>

<?php $this->beginPage() ?>
  <!DOCTYPE html>
  <html lang="<?= \Yii::$app->language ?>">
    <head>
      <meta charset="<?= \Yii::$app->charset ?>">
      <meta name="viewport" content="width=device-width, initial-scale=1">
        <?= Html::csrfMetaTags() ?>
      <title><?= Html::encode($seo->title) ?></title>
        <?php $this->head() ?>
    </head>
    <body>
        <?php $this->beginBody() ?>
      <!-- Google Analytics -->
      <?php if (!empty($settings->ga_code)) { ?>
      <script>
          (function(i, s, o, g, r, a, m) {
              i[ 'GoogleAnalyticsObject' ] = r;
              i[ r ] = i[ r ] || function() {
                      (i[ r ].q = i[ r ].q || []).push(arguments)
                  }, i[ r ].l = 1 * new Date();
              a = s.createElement(o), m = s.getElementsByTagName(o)[ 0 ];
              a.async = 1;
              a.src = g;
              m.parentNode.insertBefore(a, m)
          })(window, document, 'script', 'https://www.google-analytics.com/analytics.js', 'ga');

          ga('create', '<?=$settings->ga_code?>', 'auto');
          ga('send', 'pageview');
      
      </script>
      <?php } ?>

        <header id="header_" class="section-box-header">
            <div class="container">
                <div class="row">
                    <div class="col-xs-6 col-sm-3 logo-wr">
                        <a href="#">
                            <img src="/img/logo.jpg" alt="">
                        </a>
                    </div>
                    <div class="col-xs-6 col-sm-9">
                        <div class="phone-header-temp"><a href="tel:+380677638232">+380 67 763 82 32</a></div>
                    </div>

                </div>
            </div>
        </header>

        <!-- #content должен быть в main.php -->
        <div id="content_" class="section-box-content">
            <!-- start breadcrumbs -->
            <!-- если не главная выводить сюда-->
            <!-- end breadcrumbs -->

            <!-- start content -->
            <section class="items-section-temp">
                <div class="container">
                    <div class="row">
                        <div class="col-xs-6 col-sm-4 col-md-3 items-col">
                            <div class="items-img-wr my-gallery">
                                <figure class="help_class items-img">
                                    <!--макс размер картинки 228x228-->
                                    <!--в  data-size выводить оригинальный размер картинки( тот который до обрезки) и в hreff ссылка на большую картинку-->
                                    <a class="active" href="/img/temp/temp-1-1-big.jpg" itemprop="contentUrl" data-size="980x980">
                                        <img src="/img/temp/temp-1.jpg" itemprop="thumbnail" alt="" />
                                    </a>
                                    <a style="display: none;" href="/img/temp/temp-1-2-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                    <a style="display: none;" href="/img/temp/temp-1-3-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                </figure>
                            </div>
                            <div class="items-title">
                                <span>Балетки розово-желтые</span>
                            </div>
                            <div class="items-price">
                                3500 грн
                            </div>
                        </div>

                        <div class="col-xs-6 col-sm-4 col-md-3 items-col">
                            <div class="items-img-wr my-gallery">
                                <figure class="help_class items-img">
                                    <!--макс размер картинки 228x228-->
                                    <!--в  data-size выводить оригинальный размер картинки( тот который до обрезки) и в hreff ссылка на большую картинку-->
                                    <a class="active" href="/img/temp/temp-2-1-big.jpg" itemprop="contentUrl" data-size="980x980">
                                        <img src="/img/temp/temp-2.jpg" itemprop="thumbnail" alt="" />
                                    </a>
                                    <a style="display: none;" href="/img/temp/temp-2-2-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                    <a style="display: none;" href="/img/temp/temp-2-3-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                </figure>
                            </div>
                            <div class="items-title">
                                <span>Балетки сине-голубые</span>
                            </div>
                            <div class="items-price">
                                1499 грн
                            </div>
                        </div>

                        <div class="col-xs-6 col-sm-4 col-md-3 items-col">
                            <div class="items-img-wr my-gallery">
                                <figure class="help_class items-img">
                                    <!--макс размер картинки 228x228-->
                                    <!--в  data-size выводить оригинальный размер картинки( тот который до обрезки) и в hreff ссылка на большую картинку-->
                                    <a class="active" href="/img/temp/temp-2-1-big.jpg" itemprop="contentUrl" data-size="980x980">
                                        <img src="/img/temp/temp-3.jpg" itemprop="thumbnail" alt="" />
                                    </a>
                                    <a style="display: none;" href="/img/temp/temp-2-2-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                    <a style="display: none;" href="/img/temp/temp-2-3-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                </figure>
                            </div>
                            <div class="items-title">
                                <span>Лодочки 9 см темное золото</span>
                            </div>
                            <div class="items-price">
                                2200 грн
                            </div>
                        </div>

                        <div class="col-xs-6 col-sm-4 col-md-3 items-col">
                            <div class="items-img-wr my-gallery">
                                <figure class="help_class items-img">
                                    <!--макс размер картинки 228x228-->
                                    <!--в  data-size выводить оригинальный размер картинки( тот который до обрезки) и в hreff ссылка на большую картинку-->
                                    <a class="active" href="/img/temp/temp-2-1-big.jpg" itemprop="contentUrl" data-size="980x980">
                                        <img src="/img/temp/temp-4.jpg" itemprop="thumbnail" alt="" />
                                    </a>
                                    <a style="display: none;" href="/img/temp/temp-2-2-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                    <a style="display: none;" href="/img/temp/temp-2-3-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                </figure>
                            </div>
                            <div class="items-title">
                                <span>Кроссовки черные с желтым</span>
                            </div>
                            <div class="items-price">
                                2200 грн
                            </div>
                        </div>

                        <div class="col-xs-6 col-sm-4 col-md-3 items-col">
                            <div class="items-img-wr my-gallery">
                                <figure class="help_class items-img">
                                    <!--макс размер картинки 228x228-->
                                    <!--в  data-size выводить оригинальный размер картинки( тот который до обрезки) и в hreff ссылка на большую картинку-->
                                    <a class="active" href="/img/temp/temp-2-1-big.jpg" itemprop="contentUrl" data-size="980x980">
                                        <img src="/img/temp/temp-5.jpg" itemprop="thumbnail" alt="" />
                                    </a>
                                    <a style="display: none;" href="/img/temp/temp-2-2-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                    <a style="display: none;" href="/img/temp/temp-2-3-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                </figure>
                            </div>
                            <div class="items-title">
                                <span>Кроссовки бело-красные</span>
                            </div>
                            <div class="items-price">
                                2200 грн
                            </div>
                        </div>

                        <div class="col-xs-6 col-sm-4 col-md-3 items-col">
                            <div class="items-img-wr my-gallery">
                                <figure class="help_class items-img">
                                    <!--макс размер картинки 228x228-->
                                    <!--в  data-size выводить оригинальный размер картинки( тот который до обрезки) и в hreff ссылка на большую картинку-->
                                    <a class="active" href="/img/temp/temp-1-1-big.jpg" itemprop="contentUrl" data-size="980x980">
                                        <img src="/img/temp/temp-1.jpg" itemprop="thumbnail" alt="" />
                                    </a>
                                    <a style="display: none;" href="/img/temp/temp-1-2-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                    <a style="display: none;" href="/img/temp/temp-1-3-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                </figure>
                            </div>
                            <div class="items-title">
                                <span>Балетки розово-желтые</span>
                            </div>
                            <div class="items-price">
                                3500 грн
                            </div>
                        </div>

                        <div class="col-xs-6 col-sm-4 col-md-3 items-col">
                            <div class="items-img-wr my-gallery">
                                <figure class="help_class items-img">
                                    <!--макс размер картинки 228x228-->
                                    <!--в  data-size выводить оригинальный размер картинки( тот который до обрезки) и в hreff ссылка на большую картинку-->
                                    <a class="active" href="/img/temp/temp-2-1-big.jpg" itemprop="contentUrl" data-size="980x980">
                                        <img src="/img/temp/temp-2.jpg" itemprop="thumbnail" alt="" />
                                    </a>
                                    <a style="display: none;" href="/img/temp/temp-2-2-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                    <a style="display: none;" href="/img/temp/temp-2-3-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                </figure>
                            </div>
                            <div class="items-title">
                                <span>Балетки сине-голубые</span>
                            </div>
                            <div class="items-price">
                                1499 грн
                            </div>
                        </div>

                        <div class="col-xs-6 col-sm-4 col-md-3 items-col">
                            <div class="items-img-wr my-gallery">
                                <figure class="help_class items-img">
                                    <!--макс размер картинки 228x228-->
                                    <!--в  data-size выводить оригинальный размер картинки( тот который до обрезки) и в hreff ссылка на большую картинку-->
                                    <a class="active" href="/img/temp/temp-2-1-big.jpg" itemprop="contentUrl" data-size="980x980">
                                        <img src="/img/temp/temp-3.jpg" itemprop="thumbnail" alt="" />
                                    </a>
                                    <a style="display: none;" href="/img/temp/temp-2-2-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                    <a style="display: none;" href="/img/temp/temp-2-3-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                </figure>
                            </div>
                            <div class="items-title">
                                <span>Лодочки 9 см темное золото</span>
                            </div>
                            <div class="items-price">
                                2200 грн
                            </div>
                        </div>

                        <div class="col-xs-6 col-sm-4 col-md-3 items-col">
                            <div class="items-img-wr my-gallery">
                                <figure class="help_class items-img">
                                    <!--макс размер картинки 228x228-->
                                    <!--в  data-size выводить оригинальный размер картинки( тот который до обрезки) и в hreff ссылка на большую картинку-->
                                    <a class="active" href="/img/temp/temp-2-1-big.jpg" itemprop="contentUrl" data-size="980x980">
                                        <img src="/img/temp/temp-4.jpg" itemprop="thumbnail" alt="" />
                                    </a>
                                    <a style="display: none;" href="/img/temp/temp-2-2-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                    <a style="display: none;" href="/img/temp/temp-2-3-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                </figure>
                            </div>
                            <div class="items-title">
                                <span>Кроссовки черные с желтым</span>
                            </div>
                            <div class="items-price">
                                2200 грн
                            </div>
                        </div>

                        <div class="col-xs-6 col-sm-4 col-md-3 items-col">
                            <div class="items-img-wr my-gallery">
                                <figure class="help_class items-img">
                                    <!--макс размер картинки 228x228-->
                                    <!--в  data-size выводить оригинальный размер картинки( тот который до обрезки) и в hreff ссылка на большую картинку-->
                                    <a class="active" href="/img/temp/temp-2-1-big.jpg" itemprop="contentUrl" data-size="980x980">
                                        <img src="/img/temp/temp-5.jpg" itemprop="thumbnail" alt="" />
                                    </a>
                                    <a style="display: none;" href="/img/temp/temp-2-2-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                    <a style="display: none;" href="/img/temp/temp-2-3-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                </figure>
                            </div>
                            <div class="items-title">
                                <span>Кроссовки бело-красные</span>
                            </div>
                            <div class="items-price">
                                2200 грн
                            </div>
                        </div>

                        <div class="col-xs-6 col-sm-4 col-md-3 items-col">
                            <div class="items-img-wr my-gallery">
                                <figure class="help_class items-img">
                                    <!--макс размер картинки 228x228-->
                                    <!--в  data-size выводить оригинальный размер картинки( тот который до обрезки) и в hreff ссылка на большую картинку-->
                                    <a class="active" href="/img/temp/temp-2-1-big.jpg" itemprop="contentUrl" data-size="980x980">
                                        <img src="/img/temp/temp-5.jpg" itemprop="thumbnail" alt="" />
                                    </a>
                                    <a style="display: none;" href="/img/temp/temp-2-2-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                    <a style="display: none;" href="/img/temp/temp-2-3-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                </figure>
                            </div>
                            <div class="items-title">
                                <span>Кроссовки бело-красные</span>
                            </div>
                            <div class="items-price">
                                2200 грн
                            </div>
                        </div>

                        <div class="col-xs-6 col-sm-4 col-md-3 items-col">
                            <div class="items-img-wr my-gallery">
                                <figure class="help_class items-img">
                                    <!--макс размер картинки 228x228-->
                                    <!--в  data-size выводить оригинальный размер картинки( тот который до обрезки) и в hreff ссылка на большую картинку-->
                                    <a class="active" href="/img/temp/temp-1-1-big.jpg" itemprop="contentUrl" data-size="980x980">
                                        <img src="/img/temp/temp-1.jpg" itemprop="thumbnail" alt="" />
                                    </a>
                                    <a style="display: none;" href="/img/temp/temp-1-2-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                    <a style="display: none;" href="/img/temp/temp-1-3-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                </figure>
                            </div>
                            <div class="items-title">
                                <span>Балетки розово-желтые</span>
                            </div>
                            <div class="items-price">
                                3500 грн
                            </div>
                        </div>

                        <div class="col-xs-6 col-sm-4 col-md-3 items-col">
                            <div class="items-img-wr my-gallery">
                                <figure class="help_class items-img">
                                    <!--макс размер картинки 228x228-->
                                    <!--в  data-size выводить оригинальный размер картинки( тот который до обрезки) и в hreff ссылка на большую картинку-->
                                    <a class="active" href="/img/temp/temp-1-1-big.jpg" itemprop="contentUrl" data-size="980x980">
                                        <img src="/img/temp/temp-1.jpg" itemprop="thumbnail" alt="" />
                                    </a>
                                    <a style="display: none;" href="/img/temp/temp-1-2-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                    <a style="display: none;" href="/img/temp/temp-1-3-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                </figure>
                            </div>
                            <div class="items-title">
                                <span>Балетки розово-желтые</span>
                            </div>
                            <div class="items-price">
                                3500 грн
                            </div>
                        </div>

                        <div class="col-xs-6 col-sm-4 col-md-3 items-col">
                            <div class="items-img-wr my-gallery">
                                <figure class="help_class items-img">
                                    <!--макс размер картинки 228x228-->
                                    <!--в  data-size выводить оригинальный размер картинки( тот который до обрезки) и в hreff ссылка на большую картинку-->
                                    <a class="active" href="/img/temp/temp-2-1-big.jpg" itemprop="contentUrl" data-size="980x980">
                                        <img src="/img/temp/temp-2.jpg" itemprop="thumbnail" alt="" />
                                    </a>
                                    <a style="display: none;" href="/img/temp/temp-2-2-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                    <a style="display: none;" href="/img/temp/temp-2-3-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                </figure>
                            </div>
                            <div class="items-title">
                                <span>Балетки сине-голубые</span>
                            </div>
                            <div class="items-price">
                                1499 грн
                            </div>
                        </div>

                        <div class="col-xs-6 col-sm-4 col-md-3 items-col">
                            <div class="items-img-wr my-gallery">
                                <figure class="help_class items-img">
                                    <!--макс размер картинки 228x228-->
                                    <!--в  data-size выводить оригинальный размер картинки( тот который до обрезки) и в hreff ссылка на большую картинку-->
                                    <a class="active" href="/img/temp/temp-2-1-big.jpg" itemprop="contentUrl" data-size="980x980">
                                        <img src="/img/temp/temp-3.jpg" itemprop="thumbnail" alt="" />
                                    </a>
                                    <a style="display: none;" href="/img/temp/temp-2-2-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                    <a style="display: none;" href="/img/temp/temp-2-3-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                </figure>
                            </div>
                            <div class="items-title">
                                <span>Лодочки 9 см темное золото</span>
                            </div>
                            <div class="items-price">
                                2200 грн
                            </div>
                        </div>

                        <div class="col-xs-6 col-sm-4 col-md-3 items-col">
                            <div class="items-img-wr my-gallery">
                                <figure class="help_class items-img">
                                    <!--макс размер картинки 228x228-->
                                    <!--в  data-size выводить оригинальный размер картинки( тот который до обрезки) и в hreff ссылка на большую картинку-->
                                    <a class="active" href="/img/temp/temp-2-1-big.jpg" itemprop="contentUrl" data-size="980x980">
                                        <img src="/img/temp/temp-4.jpg" itemprop="thumbnail" alt="" />
                                    </a>
                                    <a style="display: none;" href="/img/temp/temp-2-2-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                    <a style="display: none;" href="/img/temp/temp-2-3-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                </figure>
                            </div>
                            <div class="items-title">
                                <span>Кроссовки черные с желтым</span>
                            </div>
                            <div class="items-price">
                                2200 грн
                            </div>
                        </div>

                        <div class="col-xs-6 col-sm-4 col-md-3 items-col">
                            <div class="items-img-wr my-gallery">
                                <figure class="help_class items-img">
                                    <!--макс размер картинки 228x228-->
                                    <!--в  data-size выводить оригинальный размер картинки( тот который до обрезки) и в hreff ссылка на большую картинку-->
                                    <a class="active" href="/img/temp/temp-2-1-big.jpg" itemprop="contentUrl" data-size="980x980">
                                        <img src="/img/temp/temp-5.jpg" itemprop="thumbnail" alt="" />
                                    </a>
                                    <a style="display: none;" href="/img/temp/temp-2-2-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                    <a style="display: none;" href="/img/temp/temp-2-3-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                </figure>
                            </div>
                            <div class="items-title">
                                <span>Кроссовки бело-красные</span>
                            </div>
                            <div class="items-price">
                                2200 грн
                            </div>
                        </div>

                        <div class="col-xs-6 col-sm-4 col-md-3 items-col">
                            <div class="items-img-wr my-gallery">
                                <figure class="help_class items-img">
                                    <!--макс размер картинки 228x228-->
                                    <!--в  data-size выводить оригинальный размер картинки( тот который до обрезки) и в hreff ссылка на большую картинку-->
                                    <a class="active" href="/img/temp/temp-1-1-big.jpg" itemprop="contentUrl" data-size="980x980">
                                        <img src="/img/temp/temp-1.jpg" itemprop="thumbnail" alt="" />
                                    </a>
                                    <a style="display: none;" href="/img/temp/temp-1-2-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                    <a style="display: none;" href="/img/temp/temp-1-3-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                </figure>
                            </div>
                            <div class="items-title">
                                <span>Балетки розово-желтые</span>
                            </div>
                            <div class="items-price">
                                3500 грн
                            </div>
                        </div>

                        <div class="col-xs-6 col-sm-4 col-md-3 items-col">
                            <div class="items-img-wr my-gallery">
                                <figure class="help_class items-img">
                                    <!--макс размер картинки 228x228-->
                                    <!--в  data-size выводить оригинальный размер картинки( тот который до обрезки) и в hreff ссылка на большую картинку-->
                                    <a class="active" href="/img/temp/temp-2-1-big.jpg" itemprop="contentUrl" data-size="980x980">
                                        <img src="/img/temp/temp-2.jpg" itemprop="thumbnail" alt="" />
                                    </a>
                                    <a style="display: none;" href="/img/temp/temp-2-2-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                    <a style="display: none;" href="/img/temp/temp-2-3-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                </figure>
                            </div>
                            <div class="items-title">
                                <span>Балетки сине-голубые</span>
                            </div>
                            <div class="items-price">
                                1499 грн
                            </div>
                        </div>

                        <div class="col-xs-6 col-sm-4 col-md-3 items-col">
                            <div class="items-img-wr my-gallery">
                                <figure class="help_class items-img">
                                    <!--макс размер картинки 228x228-->
                                    <!--в  data-size выводить оригинальный размер картинки( тот который до обрезки) и в hreff ссылка на большую картинку-->
                                    <a class="active" href="/img/temp/temp-2-1-big.jpg" itemprop="contentUrl" data-size="980x980">
                                        <img src="/img/temp/temp-3.jpg" itemprop="thumbnail" alt="" />
                                    </a>
                                    <a style="display: none;" href="/img/temp/temp-2-2-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                    <a style="display: none;" href="/img/temp/temp-2-3-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                </figure>
                            </div>
                            <div class="items-title">
                                <span>Лодочки 9 см темное золото</span>
                            </div>
                            <div class="items-price">
                                2200 грн
                            </div>
                        </div>

                        <div class="col-xs-6 col-sm-4 col-md-3 items-col">
                            <div class="items-img-wr my-gallery">
                                <figure class="help_class items-img">
                                    <!--макс размер картинки 228x228-->
                                    <!--в  data-size выводить оригинальный размер картинки( тот который до обрезки) и в hreff ссылка на большую картинку-->
                                    <a class="active" href="/img/temp/temp-2-1-big.jpg" itemprop="contentUrl" data-size="980x980">
                                        <img src="/img/temp/temp-4.jpg" itemprop="thumbnail" alt="" />
                                    </a>
                                    <a style="display: none;" href="/img/temp/temp-2-2-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                    <a style="display: none;" href="/img/temp/temp-2-3-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                </figure>
                            </div>
                            <div class="items-title">
                                <span>Кроссовки черные с желтым</span>
                            </div>
                            <div class="items-price">
                                2200 грн
                            </div>
                        </div>

                        <div class="col-xs-6 col-sm-4 col-md-3 items-col">
                            <div class="items-img-wr my-gallery">
                                <figure class="help_class items-img">
                                    <!--макс размер картинки 228x228-->
                                    <!--в  data-size выводить оригинальный размер картинки( тот который до обрезки) и в hreff ссылка на большую картинку-->
                                    <a class="active" href="/img/temp/temp-2-1-big.jpg" itemprop="contentUrl" data-size="980x980">
                                        <img src="/img/temp/temp-5.jpg" itemprop="thumbnail" alt="" />
                                    </a>
                                    <a style="display: none;" href="/img/temp/temp-2-2-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                    <a style="display: none;" href="/img/temp/temp-2-3-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                </figure>
                            </div>
                            <div class="items-title">
                                <span>Кроссовки бело-красные</span>
                            </div>
                            <div class="items-price">
                                2200 грн
                            </div>
                        </div>

                        <div class="col-xs-6 col-sm-4 col-md-3 items-col">
                            <div class="items-img-wr my-gallery">
                                <figure class="help_class items-img">
                                    <!--макс размер картинки 228x228-->
                                    <!--в  data-size выводить оригинальный размер картинки( тот который до обрезки) и в hreff ссылка на большую картинку-->
                                    <a class="active" href="/img/temp/temp-2-1-big.jpg" itemprop="contentUrl" data-size="980x980">
                                        <img src="/img/temp/temp-5.jpg" itemprop="thumbnail" alt="" />
                                    </a>
                                    <a style="display: none;" href="/img/temp/temp-2-2-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                    <a style="display: none;" href="/img/temp/temp-2-3-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                </figure>
                            </div>
                            <div class="items-title">
                                <span>Кроссовки бело-красные</span>
                            </div>
                            <div class="items-price">
                                2200 грн
                            </div>
                        </div>

                        <div class="col-xs-6 col-sm-4 col-md-3 items-col">
                            <div class="items-img-wr my-gallery">
                                <figure class="help_class items-img">
                                    <!--макс размер картинки 228x228-->
                                    <!--в  data-size выводить оригинальный размер картинки( тот который до обрезки) и в hreff ссылка на большую картинку-->
                                    <a class="active" href="/img/temp/temp-1-1-big.jpg" itemprop="contentUrl" data-size="980x980">
                                        <img src="/img/temp/temp-1.jpg" itemprop="thumbnail" alt="" />
                                    </a>
                                    <a style="display: none;" href="/img/temp/temp-1-2-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                    <a style="display: none;" href="/img/temp/temp-1-3-big.jpg" itemprop="contentUrl" data-size="980x980"></a>
                                </figure>
                            </div>
                            <div class="items-title">
                                <span>Балетки розово-желтые</span>
                            </div>
                            <div class="items-price">
                                3500 грн
                            </div>
                        </div>
                    </div>
                </div>
            </section>

            <section class="section-contacts-footer">
                <div class="contacts-footer-col"></div>
                <div class="contacts-footer-col map_ hidden-xs"></div>
                <div class="container">
                    <div class="row">
                        <div class="col-xs-12 col-sm-6 contacts-footer-col">
                            <div class="contacts-footer-wr">
                                <div class="c-f-title">шоу-рум</div>
                                <div class="c-f-adress">Киев, ул. Большая Васильковская 66</div>
                                <div class="c-f-phone">+380 67 763 82 32</div>
                                <div class="c-f-email">email: <a href="mailto:info.ambshoes@gmail.com">info.ambshoes@gmail.com</a></div>
                            </div>
                        </div>
                    </div>
                </div>
            </section>


            <!-- end content -->

        </div>

        <footer id="footer_" class="section-box-footer" >



            <div class="section-box studio_footer">
                <div class="container">
                    <div class="row">
                        <div class="hidden visible_all col-xs-12 col-sm-6">
                            <div class="copyright">© AMB SHOES 2018</div>
                        </div>
                    </div>
                </div>
            </div>


            <div style="display: none;" class="btn_up"></div>
        </footer>


        <div class="pswp" tabindex="-1" role="dialog" aria-hidden="true">

            <!-- Background of PhotoSwipe.
				 It's a separate element as animating opacity is faster than rgba(). -->
            <div class="pswp__bg"></div>

            <!-- Slides wrapper with overflow:hidden. -->
            <div class="pswp__scroll-wrap">

                <!-- Container that holds slides.
					PhotoSwipe keeps only 3 of them in the DOM to save memory.
					Don't modify these 3 pswp__item elements, data is added later on. -->
                <div class="pswp__container">
                    <div class="pswp__item"></div>
                    <div class="pswp__item"></div>
                    <div class="pswp__item"></div>
                </div>

                <!-- Default (PhotoSwipeUI_Default) interface on top of sliding area. Can be changed. -->
                <div class="pswp__ui pswp__ui--hidden">

                    <div class="pswp__top-bar">

                        <!--  Controls are self-explanatory. Order can be changed. -->

                        <div class="pswp__counter"></div>

                        <button class="pswp__button pswp__button--close" title="Close (Esc)"></button>

                        <button class="pswp__button pswp__button--share" title="Share"></button>

                        <button class="pswp__button pswp__button--fs" title="Toggle fullscreen"></button>

                        <button class="pswp__button pswp__button--zoom" title="Zoom in/out"></button>

                        <!-- Preloader demo http://codepen.io/dimsemenov/pen/yyBWoR -->
                        <!-- element will get class pswp__preloader--active when preloader is running -->
                        <div class="pswp__preloader">
                            <div class="pswp__preloader__icn">
                                <div class="pswp__preloader__cut">
                                    <div class="pswp__preloader__donut"></div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="pswp__share-modal pswp__share-modal--hidden pswp__single-tap">
                        <div class="pswp__share-tooltip"></div>
                    </div>

                    <button class="pswp__button pswp__button--arrow--left" title="Previous (arrow left)">
                    </button>

                    <button class="pswp__button pswp__button--arrow--right" title="Next (arrow right)">
                    </button>

                    <div class="pswp__caption">
                        <div class="pswp__caption__center"></div>
                    </div>

                </div>

            </div>

        </div>
        <script type="text/javascript">
            (function($) {
                var indexMinimg = 0;

                var $pswp = $('.pswp')[0];
                var image = [];

                $('.my-gallery').each( function() {
                    var $pic     = $(this),
                        getItems = function() {
                            var items = [];
                            $pic.find('a').each(function() {
                                var $href   = $(this).attr('href'),
                                    $size   = $(this).data('size').split('x'),
                                    $width  = $size[0],
                                    $height = $size[1];

                                if(!($(this).data('type') == 'video')){
                                    var item = {
                                        src : $href,
                                        w   : $width,
                                        h   : $height
                                    }
                                } else {
                                    item = {
                                        html: '<div class="wrapper">' + $(this).data('video') + '</div>'
                                    };

                                }



                                items.push(item);
                            });
                            return items;
                        }

                    var items = getItems();

                    $.each(items, function(index, value) {
                        image[index]     = new Image();
                        image[index].src = value['src'];
                    });

                    $pic.on('click', 'figure', function(event) {
                        event.preventDefault();
//                var $index = $(this).index();
                        var options = {
                            index: indexMinimg,
                            bgOpacity: 0.7,
                            showHideOpacity: true
                        }

                        var lightBox = new PhotoSwipe($pswp, PhotoSwipeUI_Default, items, options);
                        lightBox.init();
                    });


                });

                $('body').on('click', '.gallery_min div', function(event) {

                    event.preventDefault();
                    indexMinimg =  $(this).index();

                    if(!($(this).find('a').hasClass('active'))) {
                        $('.gallery_min div a').removeClass('active')
                        $(this).find('a').addClass('active')

                        $('.gallery_min div a').parent().removeClass('active')
                        $(this).find('a').parent().addClass('active')

                        var showImg = $('.my-gallery figure a');
                        showImg.css({display:'none'});
                        $(showImg[indexMinimg]).animate({opacity: 'toggle'}, {duration: 400, start: function() {
                                $(this).css('display', 'table-cell');
                            }
                        });
                        $('.help_class').removeClass('help_class')
                    }
                })


            })(jQuery);
        </script>
        <?php $this->endBody() ?>
    </body>
  </html>
<?php $this->endPage() ?>